@@ -16,7 +16,7 @@ from security.config import settings
 from .app import SecurityBackend
 
 
-logger = logging.getLogger(__name__)
+logging_logger = logging.getLogger(__name__)
 
 
 class BaseBackendWriter:
@@ -55,8 +55,8 @@ class BaseBackendWriter:
     def _call_receiver_method(self, signal_name, logger):
         try:
             getattr(self, signal_name)(logger)
-        except Exception:
-            logger.error(f'Cannot write log {signal_name} for writer {self._name}', exc_info=True)
+        except:
+            logging_logger.error(f'Cannot write log {signal_name} for writer {self._name}', exc_info=True)
 
     def _get_receiver(self, signal_name):
         def _log_receiver(sender, logger, signal, **kwargs):
